import sys
from pathlib import Path

import pytest
from ordeq.framework._registry import NODE_REGISTRY


@pytest.fixture
def resources_dir() -> Path:
    """Return the path to the resources directory.

    Returns:
        the path to the resources directory
    """

    PACKAGE_DIR = Path(__file__).resolve().parent
    return PACKAGE_DIR / "resources"


@pytest.fixture(autouse=True)
def append_resources_dir_to_sys_path(resources_dir):
    """Append the resources directory to sys.path."""
    sys.path.append(str(resources_dir))
    yield
    sys.path.remove(str(resources_dir))
    for n in filter(lambda m: m.startswith("example"), list(sys.modules)):
        # Remove the example.* and example2.* modules from sys.modules
        # to ensure a clean state for each test
        del sys.modules[n]
    NODE_REGISTRY._data.clear()



from ordeq import node

from example.catalog import (  # ty: ignore[unresolved-import]
    TestInput2,
    TestOutput2,
)


@node(inputs=[TestInput2], outputs=[TestOutput2])
def transform_input_2(input_data: str) -> str:
    """A simple node that transforms input data.

    Args:
        input_data: Input data as a string.

    Returns:
        The transformed input data.
    """
    return input_data.strip()




import sys
from pathlib import Path
from unittest.mock import MagicMock, patch

import pytest
from ordeq_viz_cli import main, parse_args


@pytest.mark.parametrize(
    ("args", "expected"),
    [
        (
            (
                "--package",
                "example1.a1",
                "--fmt",
                "kedro",
                "--output",
                "output_dir",
            ),
            {
                "packages": ["example1.a1"],
                "fmt": "kedro",
                "output": Path("output_dir"),
            },
        ),
        (
            (
                "--package",
                "example1.a1",
                "example2.a2",
                "--fmt",
                "kedro",
                "--output",
                "output_dir",
            ),
            {
                "packages": ["example1.a1", "example2.a2"],
                "fmt": "kedro",
                "output": Path("output_dir"),
            },
        ),
        (
            (
                "--package",
                "example1.a1",
                "--fmt",
                "mermaid",
                "--output",
                "output_dir",
            ),
            {
                "packages": ["example1.a1"],
                "fmt": "mermaid",
                "output": Path("output_dir"),
            },
        ),
        (
            # This test case checks that the parser only parses known args.
            (
                "--package",
                "example1.a1",
                "--fmt",
                "mermaid",
                "--output",
                "output_dir",
                "--unknown-arg",
                "value",
            ),
            {
                "packages": ["example1.a1"],
                "fmt": "mermaid",
                "output": Path("output_dir"),
            },
        ),
    ],
)
def test_it_parses(args, expected):
    assert vars(parse_args(args)) == expected


@patch("ordeq_viz_cli.viz")
def test_it_calls_viz(mocked_viz: MagicMock):
    with patch.object(
        sys,
        "argv",
        [
            "ordeq-viz",
            "--package",
            "example1.a1",
            "--fmt",
            "kedro",
            "--output",
            "output_dir",
        ],
    ):
        main()
    mocked_viz.assert_called_once_with(
        "example1.a1", output=Path("output_dir"), fmt="kedro"
    )



import sys
from pathlib import Path
from unittest.mock import patch

from ordeq_viz_cli import main


def test_runs_viz(tmp_path: Path):
    output_file = tmp_path / "output.mermaid"
    with patch.object(
        sys,
        "argv",
        [
            "ordeq-viz",
            "--package",
            "example",
            "--fmt",
            "mermaid",
            "--output",
            str(output_file),
        ],
    ):
        main()
    assert output_file.exists()
    output_file_content = output_file.read_text("utf8")
    assert "graph TB" in output_file_content
    assert "transform_input_2" in output_file_content
